==> stringi_0.5-5.tar.gz: stringi/src/stri_container_integer.h <==
/* This file is part of the 'stringi' package for R.
 * Copyright (C) 2013-2015, Marek Gagolewski and Bartek Tartanus
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 * this list of conditions and the following disclaimer in the documentation
 * and/or other materials provided with the distribution.
 *
 * 3. Neither the name of the copyright holder nor the names of its
 * contributors may be used to endorse or promote products derived from
 * this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING,
 * BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE
 * OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */


#ifndef __stri_container_integer_h
#define __stri_container_integer_h

#include "stri_container_base.h"


/**
 * A wrapper-class for R integer vectors
 *
 * @version 0.1-?? (Marek Gagolewski, 2013-06-15)
 */
class StriContainerInteger : public StriContainerBase {

   private:

      int* data;

   public:

      StriContainerInteger() : StriContainerBase()
      {
         data = NULL;
      }

      StriContainerInteger(SEXP rvec, R_len_t _nrecycle)
      {
         this->data = NULL;
#ifndef NDEBUG
         if (!Rf_isInteger(rvec))
            throw StriException("DEBUG: !isInteger in StriContainerInteger");
#endif
         R_len_t ndata = LENGTH(rvec);
         this->init_Base(ndata, _nrecycle, true);
         this->data = INTEGER(rvec);
      }

      //  StriContainerInteger(StriContainerInteger& container); // default-shallow
      // ~StriContainerInteger(); // default-shallow
      //  StriContainerInteger& operator=(StriContainerInteger& container); // default-shallow


      /** check if the vectorized ith element is NA
       * @param i index
       * @return true if is NA
       */
      inline bool isNA(R_len_t i) const {
#ifndef NDEBUG
         if (i < 0 || i >= nrecycle)
            throw StriException("StriContainerInteger::isNA(): INDEX OUT OF BOUNDS");
#endif
         return (data[i%n] == NA_INTEGER);
      }


      /** get the vectorized ith element
       * @param i index
       * @return integer
       */
      inline int get(R_len_t i) const {
#ifndef NDEBUG
         if (i < 0 || i >= nrecycle)
            throw StriException("StriContainerInteger::get(): INDEX OUT OF BOUNDS");
         if (data[i%n] == NA_INTEGER)
            throw StriException("StriContainerInteger::get(): isNA");
#endif
         return (data[i%n]);
      }
};

#endif

==> stringi_1.8.4.tar.gz: stringi/src/stri_container_integer.h <==
/* This file is part of the 'stringi' project.
 * Copyright (c) 2013-2024, Marek Gagolewski <https://www.gagolewski.com/>
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 * this list of conditions and the following disclaimer in the documentation
 * and/or other materials provided with the distribution.
 *
 * 3. Neither the name of the copyright holder nor the names of its
 * contributors may be used to endorse or promote products derived from
 * this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING,
 * BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE
 * OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */


#ifndef __stri_container_integer_h
#define __stri_container_integer_h

#include "stri_container_base.h"


/**
 * A wrapper-class for R integer vectors
 *
 * @version 0.1-?? (Marek Gagolewski, 2013-06-15)
 */
class StriContainerInteger : public StriContainerBase {

private:

    int* data;

public:

    StriContainerInteger() : StriContainerBase()
    {
        data = NULL;
    }

    StriContainerInteger(SEXP rvec, R_len_t _nrecycle)
    {
        this->data = NULL;
#ifndef NDEBUG
        if (!Rf_isInteger(rvec))
            throw StriException("DEBUG: !isInteger in StriContainerInteger");
#endif
        R_len_t ndata = LENGTH(rvec);
        this->init_Base(ndata, _nrecycle, true);
        this->data = INTEGER(rvec);  // TODO: ALTREP will be problematic?
    }

    //  StriContainerInteger(StriContainerInteger& container); // default-shallow
    // ~StriContainerInteger(); // default-shallow
    //  StriContainerInteger& operator=(StriContainerInteger& container); // default-shallow


    /** check if the vectorized ith element is NA
     * @param i index
     * @return true if is NA
     */
    inline bool isNA(R_len_t i) const {
#ifndef NDEBUG
        if (i < 0 || i >= nrecycle)
            throw StriException("StriContainerInteger::isNA(): INDEX OUT OF BOUNDS");
#endif
        return (data[i%n] == NA_INTEGER);
    }


    /** get the vectorized ith element
     *
     * @param i index
     * @return integer
     */
    inline int get(R_len_t i) const {
#ifndef NDEBUG
        if (i < 0 || i >= nrecycle)
            throw StriException("StriContainerInteger::get(): INDEX OUT OF BOUNDS");
        if (data[i%n] == NA_INTEGER)
            throw StriException("StriContainerInteger::get(): isNA");
#endif
        return (data[i%n]);
    }


    /** get the vectorized ith element, no NA check here
     *
     * @param i index
     * @return integer
     */
    inline int getNAble(R_len_t i) const {
#ifndef NDEBUG
        if (i < 0 || i >= nrecycle)
            throw StriException("StriContainerInteger::get(): INDEX OUT OF BOUNDS");
#endif
        return (data[i%n]);
    }
};

#endif
